==> haskell-one-liner-2.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-1SExUFU96CWFU03nmfy82k
key:                  one-liner-2.1-1SExUFU96CWFU03nmfy82k
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  b5c6e493728a7b4ab8f6f30491ba5c91
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-1SExUFU96CWFU03nmfy82k
depends:
    base-4.17.2.1 bifunctors-5.6-9UAdy2Rz8TK2BlMm8XQUvc
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.3.1-DzmrB4gP7xq9lyt9SyUzvZ
    profunctors-5.6.2-FCezC193SLE8IKnRHeV6TK
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-one-liner-2.1-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-KHeK4OcnaiHLGa5RaZnmZf
key:                  one-liner-2.1-KHeK4OcnaiHLGa5RaZnmZf
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  6ec295c069188acf68d5bc77a0d5d103
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-KHeK4OcnaiHLGa5RaZnmZf
depends:
    base-4.17.2.1 bifunctors-5.6-10TuipejvSl5iLwFVhSywc
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.3.1-F01tNNz220J6PJf3Py6ABa
    profunctors-5.6.2-FU1ZJ7jAwY3FBezLPRDd4l
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
